@@ -78,7 +78,10 @@ func TestRenderLineEmpty(t *testing.T) {
 
 	rendered, count := renderLine(row)
 	assert.Equal(t, count, 0)
-	assert.Equal(t, rendered, "")
+
+	// All lines are expected to stand on their own, so we always need to clear
+	// to EOL whether or not the line is empty.
+	assert.Equal(t, rendered, "\x1b[m\x1b[K")
 }
 
 func TestRenderLineLastReversed(t *testing.T) {
@@ -152,7 +155,10 @@ func TestRenderLineOnlyTrailingSpaces(t *testing.T) {
 
 	rendered, count := renderLine(row)
 	assert.Equal(t, count, 0)
-	assert.Equal(t, rendered, "")
+
+	// All lines are expected to stand on their own, so we always need to clear
+	// to EOL whether or not the line is empty.
+	assert.Equal(t, rendered, "\x1b[m\x1b[K")
 }
 
 func TestRenderLineLastReversedSpaces(t *testing.T) {
